@@ -21,7 +21,7 @@ class Cliente(core.models.Log, core.models.PessoaLog):
 class Endereco(core.models.Log, core.models.EnderecoComplementoLog):
     cliente = models.ForeignKey('cliente.Cliente', on_delete=models.DO_NOTHING, null=True)
     codigo = models.IntegerField(default=1, null=True)
-    ist_principal = models.BooleanField(default=True, null=True)
+    is_principal = models.BooleanField(default=True, null=True)
 
     apelido = models.CharField(max_length=200, null=True)
 
